# Resea SDK
[![Build Status](https://travis-ci.org/resea/sdk.svg?branch=master)](https://travis-ci.org/resea/sdk)
[![Coverage Status](https://coveralls.io/repos/resea/sdk/badge.svg?branch=master&service=github)](https://coveralls.io/github/resea/sdk?branch=master)
[![PyPI version](https://badge.fury.io/py/reseasdk.svg)](http://badge.fury.io/py/reseasdk)

Development tools for Resea.

## Installation
```
# pip3 install reseasdk
```

## Quickstart
```
$ reseasdk new hello # create a project directory
$ cd hello
$ reseasdk test      # build and run "Hello World" program
```

## Commands
- **new**: create a project directory
- **scaffold**: generate boilerplate files
- **build**: build
- **run**: build & run
- **test**: build & test
